@@ -18,26 +18,36 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 # THE SOFTWARE.
 
-from ansiblelint import AnsibleLintRule
-import six
+from typing import Any, Dict, Union
+
+from ansiblelint.rules import AnsibleLintRule
 
 
 class OctalPermissionsRule(AnsibleLintRule):
-    id = '202'
+    id = 'risky-octal'
     shortdesc = 'Octal file permissions must contain leading zero or be a string'
     description = (
         'Numeric file permissions without leading zero can behave '
         'in unexpected ways. See '
-        'http://docs.ansible.com/ansible/file_module.html'
+        'https://docs.ansible.com/ansible/latest/collections/ansible/builtin/file_module.html'
     )
     severity = 'VERY_HIGH'
-    tags = ['formatting', 'ANSIBLE0009']
+    tags = ['formatting']
     version_added = 'historic'
 
-    _modules = ['assemble', 'copy', 'file', 'ini_file', 'lineinfile',
-                'replace', 'synchronize', 'template', 'unarchive']
+    _modules = [
+        'assemble',
+        'copy',
+        'file',
+        'ini_file',
+        'lineinfile',
+        'replace',
+        'synchronize',
+        'template',
+        'unarchive',
+    ]
 
-    def is_invalid_permission(self, mode):
+    def is_invalid_permission(self, mode: int) -> bool:
         # sensible file permission modes don't
         # have write bit set when read bit is
         # not set and don't have execute bit set
@@ -46,29 +56,37 @@ class OctalPermissionsRule(AnsibleLintRule):
         # group permissions and user and group permissions
         # are more generous than world permissions
 
-        other_write_without_read = (mode % 8 and mode % 8 < 4 and
-                                    not (mode % 8 == 1 and (mode >> 6) % 2 == 1))
-        group_write_without_read = ((mode >> 3) % 8 and (mode >> 3) % 8 < 4 and
-                                    not ((mode >> 3) % 8 == 1 and (mode >> 6) % 2 == 1))
-        user_write_without_read = ((mode >> 6) % 8 and (mode >> 6) % 8 < 4 and
-                                   not (mode >> 6) % 8 == 1)
+        other_write_without_read = (
+            mode % 8 and mode % 8 < 4 and not (mode % 8 == 1 and (mode >> 6) % 2 == 1)
+        )
+        group_write_without_read = (
+            (mode >> 3) % 8
+            and (mode >> 3) % 8 < 4
+            and not ((mode >> 3) % 8 == 1 and (mode >> 6) % 2 == 1)
+        )
+        user_write_without_read = (
+            (mode >> 6) % 8 and (mode >> 6) % 8 < 4 and not (mode >> 6) % 8 == 1
+        )
         other_more_generous_than_group = mode % 8 > (mode >> 3) % 8
         other_more_generous_than_user = mode % 8 > (mode >> 6) % 8
         group_more_generous_than_user = (mode >> 3) % 8 > (mode >> 6) % 8
 
-        return (other_write_without_read or
-                group_write_without_read or
-                user_write_without_read or
-                other_more_generous_than_group or
-                other_more_generous_than_user or
-                group_more_generous_than_user)
+        return bool(
+            other_write_without_read
+            or group_write_without_read
+            or user_write_without_read
+            or other_more_generous_than_group
+            or other_more_generous_than_user
+            or group_more_generous_than_user
+        )
 
-    def matchtask(self, file, task):
+    def matchtask(self, task: Dict[str, Any]) -> Union[bool, str]:
         if task["action"]["__ansible_module__"] in self._modules:
             mode = task['action'].get('mode', None)
 
-            if isinstance(mode, six.string_types):
+            if isinstance(mode, str):
                 return False
 
             if isinstance(mode, int):
                 return self.is_invalid_permission(mode)
+        return False
