@@ -1,15 +1,19 @@
 # Copyright (c) 2016, Tsukinowa Inc. <info@tsukinowa.jp>
 # Copyright (c) 2018, Ansible Project
 
-from ansiblelint import AnsibleLintRule
+from typing import Any, Dict, Union
+
+from ansiblelint.rules import AnsibleLintRule
 
 
 class RoleRelativePath(AnsibleLintRule):
-    id = '404'
+    id = 'no-relative-paths'
     shortdesc = "Doesn't need a relative path in role"
-    description = '``copy`` and ``template`` do not need to use relative path for ``src``'
+    description = (
+        '``copy`` and ``template`` do not need to use relative path for ``src``'
+    )
     severity = 'HIGH'
-    tags = ['module']
+    tags = ['idiom']
     version_added = 'v4.0.0'
 
     _module_to_path_folder = {
@@ -19,7 +23,7 @@ class RoleRelativePath(AnsibleLintRule):
         'win_template': 'win_templates',
     }
 
-    def matchtask(self, file, task):
+    def matchtask(self, task: Dict[str, Any]) -> Union[bool, str]:
         module = task['action']['__ansible_module__']
         if module not in self._module_to_path_folder:
             return False
@@ -30,3 +34,5 @@ class RoleRelativePath(AnsibleLintRule):
         path_to_check = '../{}'.format(self._module_to_path_folder[module])
         if path_to_check in task['action']['src']:
             return True
+
+        return False
