@@ -1,10 +1,12 @@
 import re
+from typing import Any, Dict, Union
 
-from ansiblelint import AnsibleLintRule
+from ansiblelint.rules import AnsibleLintRule
+from ansiblelint.utils import convert_to_boolean
 
 
 class ShellWithoutPipefail(AnsibleLintRule):
-    id = '306'
+    id = 'risky-shell-pipe'
     shortdesc = 'Shells that use pipes should set the pipefail option'
     description = (
         'Without the pipefail option set, a shell command that '
@@ -18,10 +20,10 @@ class ShellWithoutPipefail(AnsibleLintRule):
     tags = ['command-shell']
     version_added = 'v4.1.0'
 
-    _pipefail_re = re.compile(r"^\s*set.*-[A-z]*o\s*pipefail")
+    _pipefail_re = re.compile(r"^\s*set.*[+-][A-z]*o\s*pipefail", re.M)
     _pipe_re = re.compile(r"(?<!\|)\|(?!\|)")
 
-    def matchtask(self, file, task):
+    def matchtask(self, task: Dict[str, Any]) -> Union[bool, str]:
         if task["__ansible_action_type__"] != "task":
             return False
 
@@ -32,7 +34,11 @@ class ShellWithoutPipefail(AnsibleLintRule):
             return False
 
         unjinjad_cmd = self.unjinja(
-            ' '.join(task["action"].get("__ansible_arguments__", [])))
+            ' '.join(task["action"].get("__ansible_arguments__", []))
+        )
 
-        return (self._pipe_re.search(unjinjad_cmd) and
-                not self._pipefail_re.match(unjinjad_cmd))
+        return bool(
+            self._pipe_re.search(unjinjad_cmd)
+            and not self._pipefail_re.search(unjinjad_cmd)
+            and not convert_to_boolean(task['action'].get('ignore_errors', False))
+        )
